dijit/layout/BorderContainer Test

## dijit/layout/BorderContainer tests

Headline layout (default), left is constrained - min:150, max:250

top bar (resizable)
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
right (fixed size)

Sidebar layout, BiDi sensitive, liveSplitters: false

leading (fixed size)
top bar (fixed size)
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
bottom bar (resizable)
trailing (resizable)

gutters=false layout

leading
top bar
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
bottom bar
trailing

Vertical panels only with splitters

top bar
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
bottom bar

More fun with layouts

top a
top b
bottom c
bottom d
leading e
leading f
trailing g
trailing g

Watching the splitter events

Top:
Left
Center

Splitter coords output:

nothing moving

## dijit/layout/BorderContainer programmatic test